@@ -20,8 +20,8 @@ package org.apache.hertzbeat.collector.collect;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.hertzbeat.collector.dispatch.CollectDataDispatch;
 import org.apache.hertzbeat.collector.dispatch.MetricsCollect;
-import org.apache.hertzbeat.collector.dispatch.timer.Timeout;
-import org.apache.hertzbeat.collector.dispatch.timer.WheelTimerTask;
+import org.apache.hertzbeat.common.timer.Timeout;
+import org.apache.hertzbeat.collector.timer.WheelTimerTask;
 import org.apache.hertzbeat.common.constants.CommonConstants;
 import org.apache.hertzbeat.common.entity.job.Job;
 import org.apache.hertzbeat.common.entity.job.Metrics;
