@@ -19,7 +19,7 @@ package org.apache.hertzbeat.warehouse.db;
 
 
 import lombok.extern.slf4j.Slf4j;
-import org.apache.hertzbeat.warehouse.store.history.vm.VictoriaMetricsProperties;
+import org.apache.hertzbeat.warehouse.store.history.tsdb.vm.VictoriaMetricsProperties;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
 import org.springframework.stereotype.Component;
 import org.springframework.web.client.RestTemplate;
