@@ -35,6 +35,7 @@ import { NzTagModule } from 'ng-zorro-antd/tag';
 import { NzTimePickerModule } from 'ng-zorro-antd/time-picker';
 import { NzTransferModule } from 'ng-zorro-antd/transfer';
 import { NzUploadModule } from 'ng-zorro-antd/upload';
+import { MarkdownComponent } from 'ngx-markdown';
 
 import { AlertCenterComponent } from './alert-center/alert-center.component';
 import { AlertGroupConvergeComponent } from './alert-group/alert-group-converge.component';
@@ -78,7 +79,8 @@ const COMPONENTS: Array<Type<void>> = [
     NzUploadModule,
     QueryBuilderModule,
     NzPaginationModule,
-    NzEmptyModule
+    NzEmptyModule,
+    MarkdownComponent
   ],
   declarations: COMPONENTS
 })
