@@ -46,11 +46,16 @@ export class MonitorFormComponent implements OnChanges {
   @Input() paramDefines!: ParamDefine[];
   @Input() advancedParamDefines!: ParamDefine[];
   @Input() paramValueMap!: Map<String, Param>;
+  @Input() sdDefines!: ParamDefine[];
+  @Input() sdParams!: Param[];
+  @Input() labelKeys!: string[];
+  @Input() labelMap!: { [key: string]: string[] };
 
   @Output() readonly formSubmit = new EventEmitter<any>();
   @Output() readonly formCancel = new EventEmitter<any>();
   @Output() readonly formDetect = new EventEmitter<any>();
   @Output() readonly hostChange = new EventEmitter<string>();
+  @Output() readonly scrapeChange = new EventEmitter<string>();
   @Output() readonly collectorChange = new EventEmitter<string>();
 
   hasAdvancedParams: boolean = false;
@@ -87,7 +92,7 @@ export class MonitorFormComponent implements OnChanges {
       });
       return;
     }
-    this.monitor.host = this.monitor.host.trim();
+    this.monitor.host = this.monitor.host ? this.monitor.host.trim() : '';
     this.monitor.name = this.monitor.name.trim();
     // todo Set the host property value separately for now
     this.params.forEach(param => {
@@ -103,7 +108,18 @@ export class MonitorFormComponent implements OnChanges {
         param.paramValue = (param.paramValue as string).trim();
       }
     });
-    this.formDetect.emit({ monitor: this.monitor, params: this.params, advancedParams: this.advancedParams, collector: this.collector });
+    this.sdParams.forEach(param => {
+      if (param.paramValue != null && typeof param.paramValue == 'string') {
+        param.paramValue = (param.paramValue as string).trim();
+      }
+    });
+    this.formDetect.emit({
+      monitor: this.monitor,
+      sdParams: this.sdParams,
+      params: this.params,
+      advancedParams: this.advancedParams,
+      collector: this.collector
+    });
   }
 
   onSubmit(formGroup: FormGroup) {
@@ -132,8 +148,14 @@ export class MonitorFormComponent implements OnChanges {
         param.paramValue = (param.paramValue as string).trim();
       }
     });
+    this.sdParams.forEach(param => {
+      if (param.paramValue != null && typeof param.paramValue == 'string') {
+        param.paramValue = (param.paramValue as string).trim();
+      }
+    });
     this.formSubmit.emit({
       monitor: this.monitor,
+      sdParams: this.sdParams,
       params: this.params,
       advancedParams: this.advancedParams,
       collector: this.collector,
@@ -145,6 +167,10 @@ export class MonitorFormComponent implements OnChanges {
     this.formCancel.emit();
   }
 
+  onScrapeChange(scrape: string) {
+    this.scrapeChange.emit(scrape);
+  }
+
   onHostChange(host: string) {
     this.hostChange.emit(host);
   }
@@ -193,6 +219,17 @@ export class MonitorFormComponent implements OnChanges {
         }
       }
     });
+    this.sdDefines.forEach((paramDefine, index) => {
+      if (paramDefine.depend) {
+        let fieldValues = new Map(Object.entries(paramDefine.depend)).get(dependField);
+        if (fieldValues) {
+          this.sdParams[index].display = false;
+          if (fieldValues.map(String).includes(dependValue)) {
+            this.sdParams[index].display = true;
+          }
+        }
+      }
+    });
     this.advancedParamDefines.forEach((advancedParamDefine, index) => {
       if (advancedParamDefine.depend) {
         let fieldValues = new Map(Object.entries(advancedParamDefine.depend)).get(dependField);
