@@ -24,15 +24,13 @@ import { ALAIN_I18N_TOKEN, MenuService } from '@delon/theme';
 import { NzModalService } from 'ng-zorro-antd/modal';
 import { ModalButtonOptions } from 'ng-zorro-antd/modal/modal-types';
 import { NzNotificationService } from 'ng-zorro-antd/notification';
-import { NzTableQueryParams } from 'ng-zorro-antd/table';
 import { NzUploadChangeParam } from 'ng-zorro-antd/upload';
 import { finalize } from 'rxjs/operators';
 
 import { Monitor } from '../../../pojo/Monitor';
-import { AppDefineService } from '../../../service/app-define.service';
 import { MemoryStorageService } from '../../../service/memory-storage.service';
 import { MonitorService } from '../../../service/monitor.service';
-import { findDeepestSelected } from '../../../shared/utils/common-util';
+import { findDeepestSelected, renderLabelColor } from '../../../shared/utils/common-util';
 
 @Component({
   selector: 'app-monitor-list',
@@ -47,7 +45,6 @@ export class MonitorListComponent implements OnInit, OnDestroy {
     private notifySvc: NzNotificationService,
     private monitorSvc: MonitorService,
     private storageSvc: MemoryStorageService,
-    private appDefineSvc: AppDefineService,
     private menuService: MenuService,
     @Inject(ALAIN_I18N_TOKEN) private i18nSvc: I18NService
   ) {}
@@ -492,18 +489,8 @@ export class MonitorListComponent implements OnInit, OnDestroy {
     this.notifySvc.success(this.i18nSvc.fanyi('common.notify.copy-success'), '');
   }
 
-  /**
-   * Paging callback
-   *
-   * @param params page info
-   */
-  onTablePageChange(params: NzTableQueryParams) {
-    const { pageSize, pageIndex, sort, filter } = params;
+  onPageIndexChange(pageIndex: number) {
     this.pageIndex = pageIndex;
-    this.pageSize = pageSize;
-    const currentSort = sort.find(item => item.value !== null);
-    this.currentSortField = (currentSort && currentSort.key) || null;
-    this.currentSortOrder = (currentSort && currentSort.value) || null;
     this.changeMonitorTable(this.currentSortField, this.currentSortOrder);
   }
 
@@ -517,43 +504,29 @@ export class MonitorListComponent implements OnInit, OnDestroy {
   onAppSwitchModalOpen() {
     this.appSwitchModalVisible = true;
     this.appSearchLoading = true;
-    const getHierarchy$ = this.appDefineSvc
-      .getAppHierarchy(this.i18nSvc.defaultLang)
-      .pipe(
-        finalize(() => {
-          getHierarchy$.unsubscribe();
-          this.appSearchLoading = false;
-        })
-      )
-      .subscribe(
-        message => {
-          if (message.code === 0) {
-            let appMenus: Record<string, any> = {};
-            message.data.forEach((app: any) => {
-              let menus = appMenus[app.category];
-              app.categoryLabel = this.i18nSvc.fanyi(`menu.monitor.${app.category}`);
-              if (app.categoryLabel == `menu.monitor.${app.category}`) {
-                app.categoryLabel = app.category.toUpperCase();
-              }
-              if (menus == undefined) {
-                menus = { label: app.categoryLabel, child: [app] };
-              } else {
-                menus.child.push(app);
-              }
-              appMenus[app.category] = menus;
-            });
-            this.appSearchOrigin = Object.entries(appMenus);
-            this.appSearchOrigin.sort((a, b) => {
-              return b[1].length - a[1].length;
-            });
-          } else {
-            console.warn(message.msg);
-          }
-        },
-        error => {
-          console.warn(error.msg);
-        }
-      );
+    let appMenus: Record<string, any> = {};
+    let hierarchy: any[] = this.storageSvc.getData('hierarchy');
+    hierarchy.forEach((app: any) => {
+      if (app.category == '__system__') {
+        return;
+      }
+      let menus = appMenus[app.category];
+      app.categoryLabel = this.i18nSvc.fanyi(`menu.monitor.${app.category}`);
+      if (app.categoryLabel == `menu.monitor.${app.category}`) {
+        app.categoryLabel = app.category.toUpperCase();
+      }
+      if (menus == undefined) {
+        menus = { label: app.categoryLabel, child: [app] };
+      } else {
+        menus.child.push(app);
+      }
+      appMenus[app.category] = menus;
+    });
+    this.appSearchOrigin = Object.entries(appMenus);
+    this.appSearchOrigin.sort((a, b) => {
+      return b[1].length - a[1].length;
+    });
+    this.appSearchLoading = false;
   }
 
   onAppSwitchModalCancel() {
@@ -588,33 +561,9 @@ export class MonitorListComponent implements OnInit, OnDestroy {
     );
   }
 
-  getLabelColor(key: string): string {
-    const colors = ['blue', 'green', 'orange', 'purple', 'cyan'];
-    const index = Math.abs(this.hashString(key)) % colors.length;
-    return colors[index];
-  }
-
-  private hashString(str: string): number {
-    let hash = 0;
-    for (let i = 0; i < str.length; i++) {
-      const char = str.charCodeAt(i);
-      hash = (hash << 5) - hash + char;
-      hash = hash & hash;
-    }
-    return hash;
-  }
-
-  copyMonitor() {
-    if (this.checkedMonitorIds == null || this.checkedMonitorIds.size === 0) {
-      this.notifySvc.warning(this.i18nSvc.fanyi('common.notify.no-select-delete'), '');
-      return;
-    }
-    if (this.checkedMonitorIds.size > 1) {
-      this.notifySvc.warning(this.i18nSvc.fanyi('monitor.copy.notify.one-select'), '');
-      return;
-    }
-    const monitorId = Array.from(this.checkedMonitorIds)[0];
+  protected readonly getLabelColor = renderLabelColor;
 
+  copyMonitor(monitorId: number) {
     this.monitorSvc.copyMonitor(monitorId).subscribe(
       message => {
         if (message.code === 0) {
